@@ -25,7 +25,9 @@
 #' formats:
 #' \itemize{
 #'   \item{\strong{Formatting string:} A single string will be interpreted as 
-#' a formatting string.  See the \link{FormattingStrings} documentation for 
+#' a formatting string. Formatting strings include R-style formatting codes, 
+#' and some SAS-style format names like "best" and "date". 
+#' See the \link{FormattingStrings} documentation and the sections below for 
 #' further details.}
 #'   \item{\strong{Named vector:} A named vector can serve as a lookup list or 
 #'   decode 
@@ -39,9 +41,6 @@
 #' the most flexibility and power over your formatting.  You can use 
 #' an existing formatting function from any package, or create 
 #' your own vectorized formatting function using \code{\link[base]{Vectorize}}.}
-#' \item{\strong{"best" format name:} A "best" format name of the form 
-#' "bestW", where "W" is the desired width.  The "best" format replicates the 
-#' SAS format of the same name.  See section below for further information.}
 #' }
 #' 
 #' \code{fapply} will also accept a formatting list, which can contain any 
@@ -78,6 +77,44 @@
 #' For large values, there are some differences between SAS and R in how they
 #' represent these numbers, and sometimes they will not match.
 #' 
+#' @section "date" Format:
+#' The "date" format is used to display date values in a readable
+#' character form, such as "01JAN70" or "01-JAN-1970", depending on the
+#' specified width. The word "date" is followed by the desired width,
+#' e.g. "date7" or "date9". This format replicates similar capabilities in SAS.
+#' 
+#' The format converts numeric or Date values into character strings using
+#' a pattern that depends on the width. Smaller widths display shorter forms,
+#' while larger widths display more detail. For example:
+#' 
+#' \itemize{
+#'   \item \strong{date5} -- Displays as \code{mmmyy} (e.g., "JAN70")
+#'   \item \strong{date7} -- Displays as \code{ddmmmyy} (e.g., "01JAN70")
+#'   \item \strong{date9} -- Displays as \code{ddmmmyyyy} (e.g., "01JAN1970")
+#'   \item \strong{date11} -- Displays as \code{dd-mmm-yyyy} (e.g., "01-JAN-1970")
+#' }
+#' 
+#' The "date" format accepts widths between 5 and 11. Widths outside this
+#' range are not valid and will result in an error. The default width is 7.
+#' Both \code{"dateW"} and \code{"dateW."} are accepted, the trailing dot (".")
+#' is optional and does not affect behavior.
+#' 
+#' For input values that are numeric, the function will interpret them as
+#' the number of days since 1970-01-01, consistent with R's internal date
+#' representation. If the input
+#' is already an R \code{Date} or \code{POSIXt} object, it will be used directly. 
+#' Missing values will be returned as missing.
+#' 
+#' The output value is left-padded with spaces if it is shorter than the
+#' requested width, ensuring the formatted result always occupies exactly the
+#' specified number of characters. For example, for the date 1970-01-01,
+#' the result of \code{date7} is \code{"01JAN70"}, while the result of
+#' \code{date8} is \code{" 01JAN70"}, with one additional leading space.
+#' 
+#' This format has no direct equivalent in base R. The \strong{fmtr} package
+#' adds this capability for users who wish to replicate SAS-style "date"
+#' formatting behavior as closely as possible.
+#' 
 #' @param x A vector, factor, or list to apply the format to.
 #' @param format A format to be applied.
 #' @param width The desired character width of the formatted vector.  Default
@@ -200,6 +237,16 @@
 #' fapply(v7, "best6")
 #' # [1] "12.346" "1.23E6" NA       "0.1235" "123E-7"
 #' 
+#' # Example 9: "date" Format
+#' #' # Data Vector
+#' v8 <- as.Date(c("1924-02-29",NA,"1980-12-31","2019-12-31","2020-02-29","2030-08-20"))
+#' 
+#' fapply(v8, "date7")
+#' # [1] "29FEB24" NA   "31DEC80" "31DEC19" "29FEB20" "20AUG30"
+#' 
+#' fapply(v8, "date11")
+#' # [1] "29-FEB-1924" NA   "31-DEC-1980" "31-DEC-2019" "29-FEB-2020" "20-AUG-2030"
+#' 
 fapply <- function(x, format = NULL, width = NULL, justify = NULL) {
   
   # Get attribute values if available
@@ -442,47 +489,39 @@ eval_conditions_back <- function(x, conds) {
 format_vector <- function(x, fmt, udfmt = FALSE) {
  
   if ("character" %in% class(fmt)) {
-    if (any(class(x) %in% c("Date", "POSIXt"))) {
     
-      # For dates, call format
-      if (udfmt == TRUE) {
+     if (any(class(x) %in% c("numeric", "character", "integer"))) {
+      
+        bst <- grepl("^best[0-9]*\\.?$", fmt, ignore.case = TRUE)
+        datew <- grepl("^date[0-9]*\\.?$", fmt, ignore.case = TRUE)
         
-        ret <- tryCatch({suppressWarnings(format(x, format = fmt))},
-                        error = function(cond) {fmt})
-        
-      } else {
-        ret <- format(x, format = fmt)
-      }
-      
-      xin <- x
-      if (!"Date" %in% class(x))
-        xin <- as.Date(x)
-      
-      ret <- format_quarter(xin, ret, fmt)
-    
-    } else if (any(class(x) %in% c("numeric", "character", "integer"))) {
-      
-        bst <- grepl("^best.*", fmt)
-      
         if (bst) { 
           
-          wdth <- sub("best", "", fmt, fixed = TRUE)
+          wdth <- sub("best", "", tolower(fmt), fixed = TRUE)
+          wdth <-suppressWarnings(as.integer(wdth))
           
-          if (wdth == "") {
-            wdth <- 12
-          } else {
+          if (is.na(wdth)) {
             
-            wdth <- suppressWarnings(as.integer(wdth))
+            wdth = 12
             
-            if (is.na(wdth)) {
-              warning(paste0("Invalid format specification: ", fmt, "\n",
-                             "Reverting to 'best12'."))
-              wdth <- 12 
-            }
           }
           
           ret <- format_best(x, wdth)
           
+          
+        } else if (datew) {
+          
+          wdth <- sub("date", "", tolower(fmt), fixed = TRUE)
+          wdth <- suppressWarnings(as.integer(wdth))
+          
+          if (is.na(wdth)){
+            
+            wdth = 7
+            
+          }
+          
+          ret<-format_datew(x, wdth)
+          
         } else {
         
           # For numerics, call sprintf
@@ -497,10 +536,54 @@ format_vector <- function(x, fmt, udfmt = FALSE) {
         }
         
         # Find NA strings
-        nas <- ret == "NA"
+        nas <- ret %in% c("NA", " NA")
         
         # Turn NA strings back into real NA
         ret <- replace(ret, nas, NA)
+        
+    } else if ( any( class(x) %in% c("Date", "POSIXt"))){
+      
+      datew <- grepl("^date[0-9]*\\.?$", fmt, ignore.case = TRUE)
+      
+      
+      if (datew){
+        
+        
+        wdth <- sub("date", "", tolower(fmt), fixed = TRUE)
+        wdth <-suppressWarnings(as.integer(wdth))
+        
+        if (is.na(wdth)){
+          
+          wdth = 7
+          
+        }
+        
+        ret <- format_datew(x, wdth)
+        
+        # Find NA strings
+        nas <- ret == " NA"
+        
+        # Turn NA strings back into real NA
+        ret <- replace(ret, nas, NA)
+        
+      } else {
+        
+        if (udfmt == TRUE) {
+          
+          ret <- tryCatch({suppressWarnings(format(x, format = fmt))},
+                          error = function(cond) {fmt})
+          
+        } else {
+          ret <- format(x, format = fmt)
+        }
+        
+        xin <- x
+        if (!"Date" %in% class(x))
+          xin <- as.Date(x)
+        
+        ret <- format_quarter(xin, ret, fmt)
+      }
+      
     } else {
       ret <- fmt
     }
